Welcome to ClientVPS Mirrors

Help for package linemap
Type: Package
Title: Line Maps
Version: 0.3.0
Description: Create maps made of lines. The package contains one function: linemap(). linemap() displays a map made of lines using a raster or gridded data.
URL: https://github.com/riatelab/linemap
BugReports: https://github.com/riatelab/linemap/issues
Depends: R (≥ 3.3.0)
Imports: graphics, terra
Suggests: tinytest, covr
License: GPL-3
Encoding: UTF-8
RoxygenNote: 7.2.3
NeedsCompilation: no
Packaged: 2023-11-28 15:36:57 UTC; tim
Author: Timothée Giraud ORCID iD [cre, aut]
Maintainer: Timothée Giraud <timothee.giraud@cnrs.fr>
Repository: CRAN
Date/Publication: 2023-11-28 16:30:06 UTC

Create Line Map

Description

Plot a line map.

Usage

linemap(
  x,
  k = 2,
  threshold = 1,
  col = "white",
  border = "black",
  lwd = 0.5,
  bg = par("bg"),
  add = FALSE
)

Arguments

x

a data.frame (x, y, value), a terra SpatRaster.

k

expension factor.

threshold

threshold of the data to plot.

col

color for the lines areas.

border

color for the lines borders.

lwd

thickness of the lines.

bg

background color

add

if TRUE add the lines to the current plot.

Examples

ras <- terra::rast(system.file("tif/elevation.tif", package = "linemap"))
linemap(ras, k = 7)

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.